# Internationalization

## Table of Contents

- [Usage](#usage)

- [Supported Languages](#supported-languages)

- [Adding New Language](#adding-new-language)

## Usage

**Important! Note that non-CommonJS packages (Bower, CDN)
don't support I18n yet.** Please [vote for the issue](https://github.com/date-fns/date-fns/issues/232)
if you want to make it happen.

There are just a few functions that support I18n:

- [`format`](https://date-fns.org/docs/format)
- [`distanceInWords`](https://date-fns.org/docs/distanceInWords)
- [`distanceInWordsToNow`](https://date-fns.org/docs/distanceInWordsToNow)
- [`distanceInWordsStrict`](https://date-fns.org/docs/distanceInWordsStrict)

To use a locale, you need to require it and then pass
as an option to a function:

```js
var distanceInWords = require('date-fns/distance_in_words')
// Require Esperanto locale
var eoLocale = require('date-fns/locale/eo')

var result = distanceInWords(
  new Date(2016, 7, 1),
  new Date(2015, 0, 1),
  {locale: eoLocale} // Pass the locale as an option
)
//=> 'pli ol 1 jaro'
```

It might seem complicated to require and pass locales as options,
but unlike Moment.js which bloats your build with all the locales
by default date-fns forces developer to manually require locales when needed.
To make API simple, we encourage you to write tiny wrappers and use those
instead of original functions:

```js
// app/_lib/format.js

var format = require('date-fns/format')

var locales = {
  en: require('date-fns/locale/en'),
  eo: require('date-fns/locale/eo'),
  ru: require('date-fns/locale/ru')
}

module.exports = function (date, formatStr) {
  return format(date, formatStr, {
    locale: locales[window.__localeId__] // or global.__localeId__
  })
}

// Later:

var format = require('app/_lib/format')

window.__localeId__ = 'en'
format(friday13, 'dddd D')
//=> 'Friday 13'

window.__localeId__ = 'eo'
format(friday13, 'dddd D')
//=> 'vendredo 13'
```

## Supported Languages

date-fns currently supports:

1. [English](https://github.com/date-fns/date-fns/tree/master/src/locale/en)
  (`en`; it's the built-in language and doesn't require any setup)
2. [Russian](https://github.com/date-fns/date-fns/tree/master/src/locale/ru) (`ru`)
3. [Esperanto](https://github.com/date-fns/date-fns/tree/master/src/locale/eo) (`eo`)
4. [Chinese Simplified](https://github.com/date-fns/date-fns/tree/master/src/locale/zh_cn)
  (`zh_cn`; kudos to Changyu Geng [@KingMario](https://github.com/KingMario)
  and Song Shuoyun [@fnlctrl](https://github.com/fnlctrl))
5. [German](https://github.com/date-fns/date-fns/tree/master/src/locale/de)
  (`de`; kudos to Thomas Eilmsteiner [@DeMuu](https://github.com/DeMuu)
  and Asia [@asia-t](https://github.com/asia-t))
6. [Japanese](https://github.com/date-fns/date-fns/tree/master/src/locale/ja)
  (`ja`; kudos to Thomas Eilmsteiner [@DeMuu](https://github.com/DeMuu)
  and Yamagishi Kazutoshi [@ykzts](https://github.com/ykzts))
7. [Spanish](https://github.com/date-fns/date-fns/tree/master/src/locale/es)
  (`es`; kudos to Juan Angosto [@juanangosto](https://github.com/juanangosto),
  Guillermo Grau [@guigrpa](https://github.com/guigrpa)
  and Fernando Agüero [@fjaguero](https://github.com/fjaguero))
8. [Dutch](https://github.com/date-fns/date-fns/tree/master/src/locale/nl)
  (`nl`; kudos to Jorik Tangelder [@jtangelder](https://github.com/jtangelder)
  and Ruben Stolk [@rubenstolk](https://github.com/rubenstolk))
9. [Chinese Traditional](https://github.com/date-fns/date-fns/tree/master/src/locale/zh_tw)
  (`zh_tw`; kudos to tonypai [@tpai](https://github.com/tpai))
10. [Norwegian Bokmål](https://github.com/date-fns/date-fns/tree/master/src/locale/nb)
  (`nb`; kudos to Hans-Kristian Koren [@Hanse](https://github.com/Hanse))
11. [Catalan](https://github.com/date-fns/date-fns/tree/master/src/locale/ca)
  (`ca`; kudos to Guillermo Grau [@guigrpa](https://github.com/guigrpa))
12. [Indonesian](https://github.com/date-fns/date-fns/tree/master/src/locale/id)
  (`id`; kudos to Rahmat Budiharso [@rbudiharso](https://github.com/rbudiharso)
  and Benget Nata [@bentinata](https://github.com/bentinata))
13. [Italian](https://github.com/date-fns/date-fns/tree/master/src/locale/it)
  (`it`; kudos to Alberto Restifo [@albertorestifo](https://github.com/albertorestifo))
14. [Polish](https://github.com/date-fns/date-fns/tree/master/src/locale/pl)
  (`pl`; kudos to Mateusz Derks [@ertrzyiks](https://github.com/ertrzyiks)
  and Just RAG [@justrag](https://github.com/justrag))
15. [Portuguese](https://github.com/date-fns/date-fns/tree/master/src/locale/pt)
  (`pt`; kudos to Dário Freire [@dfreire](https://github.com/dfreire))
16. [Swedish](https://github.com/date-fns/date-fns/tree/master/src/locale/sv)
  (`sv`; kudos to Johannes Ulén [@ejulen](https://github.com/ejulen))
17. [French](https://github.com/date-fns/date-fns/tree/master/src/locale/fr)
  (`fr`; kudos to Jean Dupouy [@izeau](https://github.com/izeau)
  and François B [@fbonzon](https://github.com/fbonzon))
18. [Turkish](https://github.com/date-fns/date-fns/tree/master/src/locale/tr)
  (`tr`; kudos to Alpcan Aydın [@alpcanaydin](https://github.com/alpcanaydin))
19. [Korean](https://github.com/date-fns/date-fns/tree/master/src/locale/ko)
  (`ko`; kudos to Hong Chulju [@angdev](https://github.com/angdev))
20. [Greek](https://github.com/date-fns/date-fns/tree/master/src/locale/el)
  (`el`; kudos to Theodoros Orfanidis [@teoulas](https://github.com/teoulas))
21. [Slovak](https://github.com/date-fns/date-fns/tree/master/src/locale/sk)
  (`sk`; kudos to Marek Suscak [@mareksuscak](https://github.com/mareksuscak))
22. [Filipino](https://github.com/date-fns/date-fns/tree/master/src/locale/fil)
  (`fil`; kudos to Ian De La Cruz [@RIanDeLaCruz](https://github.com/RIanDeLaCruz))
23. [Danish](https://github.com/date-fns/date-fns/tree/master/src/locale/da)
  (`da`; kudos to Anders B. Hansen [@Andersbiha](https://github.com/Andersbiha)
  and [@kgram](https://github.com/kgram))
24. [Icelandic](https://github.com/date-fns/date-fns/tree/master/src/locale/is)
  (`is`; kudos to Derek Blank [@derekblank](https://github.com/derekblank))
25. [Finnish](https://github.com/date-fns/date-fns/tree/master/src/locale/fi)
  (`fi`; kudos to Pyry-Samuli Lahti [@Pyppe](https://github.com/Pyppe))
26. [Thai](https://github.com/date-fns/date-fns/tree/master/src/locale/th)
  (`th`; kudos to Athiwat Hirunworawongkun [@athivvat](https://github.com/athivvat))
27. [Croatian](https://github.com/date-fns/date-fns/tree/master/src/locale/hr)
  (`hr`; kudos to Matija Marohnić [@silvenon](https://github.com/silvenon))
28. [Arabic](https://github.com/date-fns/date-fns/tree/master/src/locale/ar)
  (`ar`; kudos to Abdallah Hassan [@AbdallahAHO](https://github.com/AbdallahAHO))
29. [Bulgarian](https://github.com/date-fns/date-fns/tree/master/src/locale/bg)
  (`bg`; kudos to Nikolay Stoynov [@arvigeus](https://github.com/arvigeus))
30. [Czech](https://github.com/date-fns/date-fns/tree/master/src/locale/cs)
  (`cs`; kudos to David Rus [@davidrus](https://github.com/davidrus))
31. [Macedonian](https://github.com/date-fns/date-fns/tree/master/src/locale/mk)
  (`mk`; kudos to Petar Vlahu [@vlahupetar](https://github.com/vlahupetar))
32. [Romanian](https://github.com/date-fns/date-fns/tree/master/src/locale/ro)
  (`ro`; kudos to Sergiu Munteanu [@jsergiu](https://github.com/jsergiu))

More is coming, help is welcome!

## Adding New Language

At the moment there is no definitive guide, so if you feel brave enough,
use this quick guide:

- First of all, [create an issue](https://github.com/date-fns/date-fns/issues/new?title=XXX%20language%20support&labels[]=I18n)
  so you won't overlap with others.
- Use [English locale](https://github.com/date-fns/date-fns/tree/master/src/locale/en)
  as the basis and then incrementally adjust the tests and the code.
- If you have questions or need guidance, leave a comment in the issue.

Thank you for your support!
